@@ -8,6 +8,8 @@ from .author_checker import AuthorChecker
 from .case_import_checker import CaseImportChecker
 from .module_display_checker import ModuleDisplayChecker
 from .module_show_checker import ModuleShowChecker
+from .module_print_checker import ModulePrintChecker
+
 
 def register(linter):
     linter.register_checker(FunctionCallChecker(linter))
@@ -18,4 +20,6 @@ def register(linter):
     linter.register_checker(ChainedDotFunctionsSyntaxChecker(linter))
     linter.register_checker(AuthorChecker(linter))
     linter.register_checker(CaseImportChecker(linter))
+    linter.register_checker(ModuleDisplayChecker(linter))
     linter.register_checker(ModuleShowChecker(linter))
+    linter.register_checker(ModulePrintChecker(linter))
