@@ -56,9 +56,17 @@ def module_contains_display(expression):
         contains_display_attr = False
     contains_display_func = False
     for arg in expression.value.args:
-        if isinstance(arg.parent, astroid.nodes.Call):
-            if hasattr(arg.parent.func, "name") and arg.parent.func.name == "display":
-                contains_display_func = True
+        contains_display_func = (
+            isinstance(arg.parent, astroid.nodes.Call)
+            and hasattr(arg.parent.func, "name")
+            and arg.parent.func.name == "display"
+        )
+        # if (
+        #     isinstance(arg.parent, astroid.nodes.Call)
+        #     and hasattr(arg.parent.func, "name")
+        #     and arg.parent.func.name == "display"
+        # ):
+        #     contains_display_func = True
     return (
         contains_func_attribute and contains_attrname and contains_display_attr
     ) or (contains_func_attribute and contains_display_func)
@@ -73,9 +81,12 @@ def module_contains_show(expression):
         contains_show_attr = False
     contains_show_func = False
     for arg in expression.value.args:
-        if isinstance(arg.parent, astroid.nodes.Call):
-            if hasattr(arg.parent.func, "name") and arg.parent.func.name == "show":
-                contains_show_func = True
+        if (
+            isinstance(arg.parent, astroid.nodes.Call)
+            and hasattr(arg.parent.func, "name")
+            and arg.parent.func.name == "show"
+        ):
+            contains_show_func = True
     return (contains_func_attribute and contains_attrname and contains_show_attr) or (
         contains_func_attribute and contains_show_func
     )
@@ -83,16 +94,14 @@ def module_contains_show(expression):
 
 def module_contains_print(expression):
     contains_func_attribute = hasattr(expression.value, "func")
-    # contains_attrname = hasattr(expression.value.func, "attrname")
-    # try:
-    #     contains_display_attr = expression.value.func.attrname == "print"
-    # except AttributeError:
-    #     contains_display_attr = False
     contains_print_func = False
     for arg in expression.value.args:
-        if isinstance(arg.parent, astroid.nodes.Call):
-            if hasattr(arg.parent.func, "name") and arg.parent.func.name == "print":
-                contains_print_func = True
+        if (
+            isinstance(arg.parent, astroid.nodes.Call)
+            and hasattr(arg.parent.func, "name")
+            and arg.parent.func.name == "print"
+        ):
+            contains_print_func = True
     return contains_func_attribute and contains_print_func
 
 
